##  Updating Linked Items to the Latest Version in Bulk
Follow these steps:
  1. On the navigation bar, click More > Reference Catalog > Business Capability Linking.
  2. On the reference catalog page, navigate to the Available Updates tab. Items for which updates are available are grouped as follows:
     * Deprecated: You can unlink deprecated items or change individual links to different items.
     * Outdated: You can review updates and apply changes in bulk by clicking Update all links to the latest version. To update the link for an individual item, click Update link to the latest version under the item name in the left column.


![Reviewing Reference Business Capabilities for Which Updates Are Available](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e85527a441014b5909a78a06e06e6_LowRes.png)
Reviewing Reference Business Capabilities for Which Updates Are Available
